﻿namespace Sharing.DaoShu110
{
    /// <summary>
    /// A unified format for processing data returns
    /// </summary>
    public class ApiResultR : IApiResultR
    {
        /// <summary>
        /// Represents an empty <see cref="IApiResult"/>.
        /// </summary>
        public static readonly IApiResultR Empty = new ApiResultR
        {
            rcode = 0,
            rmsg = "调用成功",
            rdata = null
        };

        /// <summary>
        /// Gets or sets the status code.
        /// </summary>
        /// <value>The status code.</value>
        public int rcode { get; set; }

        /// <summary>
        /// Gets or sets the message.
        /// </summary>
        /// <value>The message.</value>
        public string rmsg { get; set; }
        public string rdata { get; set; }

        /// <summary>
        /// Creates a new instance of <see cref="IApiResult{TResult}"/> by the specified result.
        /// </summary>
        /// <typeparam name="TResult">The type of the result.</typeparam>
        /// <param name="result">The result.</param>
        /// <param name="message">The result.</param>
        /// <returns>An instance inherited from <see cref="IApiResult{TResult}"/> interface.</returns>
        public static IApiResultR<TResult> Succeed<TResult>(TResult result, string message = "调用成功") => new ApiResultR<TResult>
        {
            rcode = 0,
            rdata = result,
            rmsg = message
        };

        public static IApiResultR Succeed(string message = "调用成功") => new ApiResultR
        {
            rcode = 0,
            rmsg = message
        };

        /// <summary>
        ///  Creates a new instance of <see cref="IApiResult"/> by the specified error message.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="statusCode">The status code</param>
        /// <returns>An instance inherited from <see cref="IApiResult"/> interface.</returns>
        public static IApiResultR Failed(string message = "调用失败", int? statusCode = null) => new ApiResultR
        {
            rcode = statusCode ?? -1,
            rmsg = message
        };

        /// <summary>
        ///  Creates a new instance of <see cref="IApiResult{TResult}"/> by the specified error message.
        /// </summary>
        /// <typeparam name="TResult">The type of the result.</typeparam>
        /// <param name="errorResult">The error result.</param>
        /// <param name="message">The message.</param>
        /// <param name="statusCode">The status code.</param>
        /// <returns>An instance inherited from <see cref="IApiResult"/> interface.</returns>
        public static IApiResultR<TResult> Failed<TResult>(TResult errorResult, string message, int? statusCode = null) => new ApiResultR<TResult>
        {
            rcode = statusCode ?? -1,
            rmsg = message,
            rdata = errorResult
        };

        /// <summary>
        /// Creates a new instance of <see cref="IApiResult"/> by the specified status code and message.
        /// </summary>
        /// <param name="statusCode">The status code.</param>
        /// <param name="message">The message.</param>
        /// <returns>An instance inherited from <see cref="IApiResult"/> interface.</returns>
        public static IApiResultR From(int statusCode, string message = null) => new ApiResultR
        {
            rcode = statusCode,
            rmsg = message
        };

        /// <summary>
        /// Creates a new instance of <see cref="IApiResult{TResult}"/> by the specified result.
        /// </summary>
        /// <typeparam name="TResult">The type of the result.</typeparam>
        /// <param name="result">The result.</param>
        /// <param name="statusCode">The status code.</param>
        /// <param name="message">The message.</param>
        /// <returns>An instance inherited from <see cref="IApiResult{TResult}"/> interface.</returns>
        public static IApiResultR<TResult> From<TResult>(TResult result, int statusCode, string message) => new ApiResultR<TResult>
        {
            rcode = statusCode,
            rmsg = message,
            rdata = result
        };
    }
}
