﻿using DotNetCore.CAP;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Sharing.Enterprise.Dtos;
using Sharing.Enterprise.Dtos.Receive;
using Sharing.Share.Dtos.Enterprise;
using Sharing.WebCore;
using XF.Domain.Repository;

namespace Sharing.Enterprise.Controllers
{
    /// <summary>
    /// 企业专班
    /// </summary>
    public class ReceiveController : BaseController
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly EnterprisePusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ICapPublisher _capPublisher;
        private readonly IRepository<ReceiveWriteResult> _receiveWriteResultRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="capPublisher"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="receiveWriteResultRepository"></param>
        public ReceiveController(IChannelConfigurationManager channelConfigurationManager, ICapPublisher capPublisher,
            EnterprisePusherProvider pusherProvider, IMapper mapper, IRepository<ReceiveWriteResult> receiveWriteResultRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _capPublisher = capPublisher;
            _receiveWriteResultRepository = receiveWriteResultRepository;
        }

        /// <summary>
        /// 查询企业专班
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost("platform/12345/selectEnterpriseList")]
        [AllowAnonymous]
        public async Task<EnRecordsDto> GetEnterpriseList(SelectEnterpriseListDto dto)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);
            var request = new SelectEnterpriseListRequest();

            var enterpriseList = _mapper.Map<SelectEnterpriseList>(dto);
            request.SetData(enterpriseList);

            var response = await pusher.SelectEnterpriseListAsync(request, HttpContext.RequestAborted);

            if (response != null)
            {
                if (response.success == true && response.data != null)
                {
                    return System.Text.Json.JsonSerializer.Deserialize<EnRecordsDto>(response.data.ToString());
                }
            }
            return new EnRecordsDto();
        }

        /// <summary>
        /// 企业服务提交办理结果
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost("api/yb12345/enterprise/writeResult")]
        [AllowAnonymous]
        public async Task<EnReponse> WriteResult(WriteResultDto dto)
        {
            //验证数据
            string strResult = dto.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return EnReponse.Failed(description: strResult);

            var data = _mapper.Map<ReceiveWriteResult>(dto);

            var id = await _receiveWriteResultRepository.AddAsync(data, HttpContext.RequestAborted);
            if (!string.IsNullOrEmpty(id))
            {
                //向业务系统推送消息
                await _capPublisher.PublishAsync(Sharing.Share.Mq.EventNames.SharingDataExchange, _mapper.Map<DataWriteResultDto>(dto), cancellationToken: HttpContext.RequestAborted);
                //这里往业务系统推送数据
                return EnReponse.Success("回复提交成功");
            }
            return EnReponse.Failed("接口调用失败！");
        }
    }
}
