﻿using MapsterMapper;
using MediatR;
using Sharing.Enterprise.Dtos.Send;
using Sharing.Notifications.Enterprise;
using XF.Domain.Repository;

namespace Sharing.Enterprise.Handlers
{
    /// <summary>
    /// 
    /// </summary>
    public class EnterpriseSendHandler : INotificationHandler<EnterpriseSendNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly EnterprisePusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<DataWorkOrderSend> _dataWorkOrderSendRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        public EnterpriseSendHandler(IChannelConfigurationManager channelConfigurationManager, EnterprisePusherProvider pusherProvider,
            IMapper mapper, IRepository<DataWorkOrderSend> dataWorkOrderSendRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _dataWorkOrderSendRepository = dataWorkOrderSendRepository;
        }

        /// <summary>
        /// 企业数据推送
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(EnterpriseSendNotification notification, CancellationToken cancellationToken)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var pushWorkOrder = _mapper.Map<PushWorkOrder>(notification.Data);
            var request = new PushWorkOrderRequest();
            request.SetData(pushWorkOrder);
            var response = await pusher.PushWorkOrderSendAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.code == 200 && response.success)
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _dataWorkOrderSendRepository.UpdateAsync(notification.Data);
            }
        }

    }
}
