﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos;
using Sharing.Province.Dtos.XieTong.Receive;
using Sharing.Province.Extensions;
using Sharing.Province.Other;
using Sharing.Province.XieTong.Receive;
using XF.Domain.Repository;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 
    /// </summary>
    public class GetCaseMaterialInfoHandler : INotificationHandler<GetCaseMaterialInfoNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly IMapper _mapper;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;
        private readonly XieTongClient _xieTongClient;
        private readonly IRepository<GetCaseMaterialInfo> _getCaseMaterialInfoRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="mapper"></param>
        /// <param name="waitingPushDataRepository"></param>
        /// <param name="xieTongClient"></param>
        /// <param name="getCaseMaterialInfoRepository"></param>
        public GetCaseMaterialInfoHandler(IChannelConfigurationManager channelConfigurationManager, IMapper mapper,
            IWaitingPushDataRepository waitingPushDataRepository, XieTongClient xieTongClient, IRepository<GetCaseMaterialInfo> getCaseMaterialInfoRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _mapper = mapper;
            _waitingPushDataRepository = waitingPushDataRepository;
            _xieTongClient = xieTongClient;
            _getCaseMaterialInfoRepository = getCaseMaterialInfoRepository;
        }

        /// <summary>
        /// 处理附件
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetCaseMaterialInfoNotification notification, CancellationToken cancellationToken)
        {
            var data = notification.DataOrder;
            //处理数据
            foreach (var item in data)
            {
                var dataReceive = _mapper.Map<GetCaseMaterialInfoModel>(item);

                //附件上传
                var result = await SendFile(dataReceive, item.FileName);

                //结果处理
                if (result == "1")
                {
                    //移除待发表数据
                    await _waitingPushDataRepository.RemoveAsync(p => p.SyncID == item.Id);

                    //更新推送表状态
                    item.SyncState = "1";
                }
                else
                {
                    item.SyncState = "2";
                }
                await _getCaseMaterialInfoRepository.UpdateAsync(item);
            }
        }

        /// <summary>
        /// 附件推送，先根据文件路径读取文件，然后将读取的文件转发到省上，目前还缺获取文件的文件流
        /// </summary>
        /// <returns></returns>
        private async Task<string> SendFile(GetCaseMaterialInfoModel dto, string fileName)
        {
            //获取配置信息
            var configProvince = _channelConfigurationManager.GetConfigurationProvince();

            //获取附件上传Token
            string strToken = await _xieTongClient.GetTokenAsync(default);

            //组装请求参数
            var model = new GetCaseMaterialInfoRequest
            {
                paras = dto,
                token = new ClientInfo(configProvince.ClientId, configProvince.ClientSecret)
            };

            Dictionary<string, object> dicParam = new Dictionary<string, object>
            {
                { "params", Newtonsoft.Json.JsonConvert.SerializeObject(model) } // 第一个接口参数，json格式字符串
            };

            // 文件内容
            byte[] file = Convert.FromBase64String("");//这里需要获取附件的流

            // 构造字典文件数据
            // 接口参数名称为files
            CFormUpload.FileParameter fileParameter = new CFormUpload.FileParameter("files", file, fileName, null);
            dicParam.Add(fileName, fileParameter);

            string strUrl = configProvince.HuiJu + "get_case_material_info";
            // 上传附件
            string strResult = CFormUpload.MultipartFormDataPost(strUrl, null, dicParam, strToken);

            var response = Newtonsoft.Json.JsonConvert.DeserializeObject<ProvinceResponse>(strResult);
            if (response != null && response.ReturnInfo != null)
            {
                //成功
                return response.ReturnInfo.Code;
            }
            return "0";
        }
    }
}
