﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using XF.Domain.Repository;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 服务工单处理过程
    /// </summary>
    public class SubmitCaseProcessHandler : INotificationHandler<SubmitCaseProcessNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<SubmitCaseProcess> _submitCaseProcessRepository;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseProcessRepository"></param>
        /// <param name="waitingPushDataRepository"></param>
        public SubmitCaseProcessHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IRepository<SubmitCaseProcess> submitCaseProcessRepository, IWaitingPushDataRepository waitingPushDataRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseProcessRepository = submitCaseProcessRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseProcessNotification notification, CancellationToken cancellationToken)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<List<CaseProcess>>(notification.DataOrder);

            var request = new SubmitCaseProcessRequest();

            //var data = new SubmitCaseProcessData
            //{
            //    CaseProcesss = new List<CaseProcess>
            //    {
            //        dataReceive
            //    }
            //};
            foreach (var item in dataReceive)
            {
                request.ForeachClass(item);
            }
            var data = new SubmitCaseProcessData
            {
                CaseProcesss = dataReceive
            };
            request.SetData(data);

            var response = await pusher.PushSubmitCaseProcessAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response != null)
                {
                    List<ErrorInfo> list = new();
                    if (response.custom != null && response.custom.errorObjs != null && response.custom.errorObjs.Count > 0)
                    {
                        list = response.custom.errorObjs;
                    }
                    foreach (var item in notification.DataOrder)
                    {
                        if (list != null && list.Count > 0)
                        {
                            if (list.Find(p => p.caseid == item.CaseId) != null)
                                item.SyncState = "2";
                            else
                                item.SyncState = "1";
                        }
                        else
                            item.SyncState = "1";

                        await _submitCaseProcessRepository.UpdateAsync(item);
                        await _waitingPushDataRepository.RemoveAsync(p => p.SyncID == item.Id);
                    }
                    //if (response.code == "1")
                    //    notification.dataorder.syncstate = "1";
                    //else
                    //    notification.dataorder.syncstate = "2";

                    //notification.dataorder.returnresult = newtonsoft.json.jsonconvert.serializeobject(response);
                    //await _submitcaseprocessrepository.updateasync(notification.dataorder);
                }
            }
        }
    }
}
